@@ -3,6 +3,8 @@ use std::fs::File;
 use std::path::PathBuf;
 use std::sync::Mutex;
 
+use crate::text_utils::path_normalize;
+
 pub static CURRENT_FILE: Lazy<Mutex<PathBuf>> = Lazy::new(|| Mutex::new(PathBuf::new()));
 
 pub fn init<P: Into<PathBuf>>(p: P) {
@@ -17,5 +19,6 @@ pub fn dist<S: AsRef<str>>(s: S) -> PathBuf {
 
 pub fn open_new<S: AsRef<str>>(s: S) -> File {
     let curr = CURRENT_FILE.lock().unwrap();
-    File::open(curr.join(s.as_ref()).as_path()).unwrap()
+    let path = path_normalize(curr.join(s.as_ref()));
+    File::open(path).unwrap()
 }
