@@ -8,12 +8,16 @@ use resource::Resource;
 use starting_prof::StartingProf;
 use std::collections::{HashMap, HashSet};
 
+use self::subclasses::Subclasses;
+
 pub mod caster_type;
 pub mod equipment;
 pub mod feature;
 pub mod multi_class_requirements;
 pub mod resource;
 pub mod starting_prof;
+pub mod subclass;
+pub mod subclasses;
 
 #[derive(Debug, Deserialize, Serialize)]
 pub struct Class {
@@ -28,4 +32,5 @@ pub struct Class {
     pub starting_prof: StartingProf,
     pub equipment: Equipment,
     pub features: Vec<Feature>,
+    pub subclasses: Subclasses,
 }
